#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-refactor-plugin-2.2.0.0-GCPIhGzvigQJzCpr4wZlxF
key:                  hls-refactor-plugin-2.2.0.0-GCPIhGzvigQJzCpr4wZlxF
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  09eff0fc48cea5a0d6c502eda311b756
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.2.0.0-GCPIhGzvigQJzCpr4wZlxF
depends:
    aeson-2.2.1.0-28ssJzlQESE12G8XLETNIx base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-5y5VYR5qIF5L6R23Ybd297 deepseq-1.4.8.1
    dlist-1.0-3kgMz6KIk692BOWE28VQNd
    extra-1.7.16-HTBQCN3DO2zH7sDTaOIuTE ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-5bw72H8k3Bw8cYCdsWeGdn
    ghcide-2.2.0.0-FjpVTF3I1rW5cU3gU0U9e3
    hls-graph-2.2.0.0-3eqLjE4pkj8muHe1oW2q
    hls-plugin-api-2.2.0.0-1K2g4OQNXqu8cEEBtrrh7t
    lens-5.3.4-4Gn3x9DAN5U4gsnCQbhlSx
    lsp-2.2.0.0-7cgEV9u8DvVDcsmYHwBDED mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    regex-applicative-0.3.4-yvQsZofe2PJVIGGJ64zxG
    regex-tdfa-1.3.2.5-2Z48wQLqPnRDongr7ozo6M
    retrie-1.2.3-7qjRLCyRUiBDcVhxmA60m1
    syb-0.7.3-L7kiOZAm9FuLsEbHYQuF8P text-2.0.2
    text-rope-0.3-13PtxrxbfWSEznkenTV65t time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

